@@ -70,7 +70,7 @@ preserve_special <- function(x, split_hyphens = TRUE, split_tags = TRUE, verbose
     hashtag <- quanteda_options("pattern_hashtag")
     # preserves web and email address
     address <- "(https?:\\/\\/(www\\.)?|@)[-a-zA-Z0-9@:%._\\+~#=]{1,256}\\.[a-z]{2,4}\\b([-a-zA-Z0-9@:%_\\+.~#?&//=]*)"
-
+    
     regex <- address
     if (!split_hyphens) {
         if (verbose) catm(" ...preserving hyphens\n")
@@ -111,7 +111,7 @@ restore_special <- function(x, special, recompile = TRUE) {
     if (!length(special))
         return(x)
 
-    type <- attr(x, "types")
+    type <- get_types(x)
     # extract all placeholders
     d <- stri_extract_all_regex(type, "\u100000\\d+\u100001", omit_no_match = TRUE)
     r <- lengths(d)
@@ -130,8 +130,8 @@ restore_special <- function(x, special, recompile = TRUE) {
             )
         }
     }
-    if (!identical(type, attr(x, "types"))) {
-        attr(x, "types") <- type
+    if (!identical(type, get_types(x))) {
+        set_types(x) <- type
     }
     return(x)
 }
@@ -159,7 +159,7 @@ tokenize_word4 <- function(x, split_hyphens = FALSE, split_tags = FALSE, split_e
     hashtag <- quanteda_options("pattern_hashtag")
     
     ftp <- "s?ftp://[-+a-zA-Z0-9@#:.%~=_&/]+"
-    http <- "(https?://)?(www.)?[-a-zA-Z0-9]+(\\.[-a-zA-Z0-9]+)+([/?#][-+a-zA-Z0-9@#:.%~=_&]+)*[/?#]?"
+    http <- "(https?://|www\\.)[-a-zA-Z0-9]+(\\.[-a-zA-Z0-9]+)+([/?#][-+a-zA-Z0-9@#:.%~=_&]+)*[/?#]?"
     email <- "[-+a-zA-Z0-9_.]+@[-a-zA-Z0-9]+(\\.[-a-zA-Z0-9]+)*\\.[a-z]+"
     regex <- c(email, ftp, http)
     if (!split_tags) {
@@ -322,14 +322,14 @@ preserve_special1 <- function(x, split_hyphens = TRUE, split_tags = TRUE, verbos
 
 # re-substitute the replacement hyphens and tags
 restore_special1 <- function(x, split_hyphens = TRUE, split_tags = TRUE) {
-    type <- attr(x, "types")
+    type <- get_types(x)
     if (!split_hyphens)
         type <- stri_replace_all_fixed(type, "_hy_", "-")
     if (!split_tags)
         type <- stri_replace_all_fixed(type, c("_ht_", "_as_"), c("#", "@"),
                                        vectorize_all = FALSE)
-    if (!identical(type, attr(x, "types"))) {
-        attr(x, "types") <- type
+    if (!identical(type, get_types(x))) {
+        set_types(x) <- type
     }
     return(x)
 }
@@ -346,7 +346,7 @@ tokenize_character <- function(x, ...) {
 #'   stri_split_boundaries stri_trim_right
 #' @export
 tokenize_sentence <- function(x, verbose = FALSE, ...) {
-    if (verbose) catm(" ...segmenting into sentences.\n")
+    if (verbose) catm(" ...segmenting into sentences\n")
     m <- names(x)
     x <- stri_replace_all_fixed(x, "\n", " ") # TODO consider removing
     x <- stri_split_boundaries(x, type = "sentence", locale = quanteda_options("tokens_locale"))
