@@ -153,7 +153,8 @@ test_that("dfm_select on a dfm returns equal feature sets", {
     dfmt2 <- dfm(tokens(txts[2:3]))
     expect_error({
         dfmt3 <- dfm_select(dfmt1, dfmt2)
-    }, "dfm cannot be used as pattern; use 'dfm_match' instead")
+    }, "The `pattern` argument of `dfm_select()` cannot be a dfm",
+    fixed = TRUE)
 })
 
 test_that("dfm_select removes padding", {
@@ -219,7 +220,7 @@ test_that("dfm_select errors when dictionary has multi-word features, issue 775"
 #     txt <- c(d1 = "a b c d e g h",  d2 = "a b e g h i j")
 #     toks_uni <- tokens(txt)
 #     dfm_uni <- dfm(toks_uni)
-#     toks_bi <- tokens(txt) %>% tokens_ngrams(n = 2, concatenator = " ")
+#     toks_bi <- tokens(txt) |> tokens_ngrams(n = 2, concatenator = " ")
 #     dfm_bi <- dfm(toks_bi)
 #     coll_bi <- textstat_collocations(toks_uni, size = 2, min_count = 2)
 #     coll_tri <- textstat_collocations(toks_uni, size = 3, min_count = 2)
@@ -266,10 +267,12 @@ test_that("dfm_remove works when selection is a dfm (#1320)", {
     d2 <- dfm(tokens("d d d a a"))
     expect_error({
         d3 <- dfm_remove(d1, pattern = d2)
-    }, "dfm cannot be used as pattern; use 'dfm_match' instead")
+    }, "The `pattern` argument of `dfm_select()` cannot be a dfm",
+    fixed = TRUE)
     expect_error({
         d4 <- dfm_select(d1, pattern = d2, selection = "remove")
-    }, "dfm cannot be used as pattern; use 'dfm_match' instead")
+    }, "The `pattern` argument of `dfm_select()` cannot be a dfm",
+    fixed = TRUE)
 })
 
 test_that("really long words are not removed in tokens() (#1713)", {
